OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Η ετικέτα συστήματος %1$s προστέθηκε από το σύστημα",
    "Added system tag {systemtag}" : "Προστέθηκε σύστημα ετικετών {systemtag}",
    "Added system tag %1$s" : "Προστέθηκε σύστημα ετικετών %1$s",
    "%1$s added system tag %2$s" : "%1$s προστέθηκε σύστημα ετικετών %2$s",
    "{actor} added system tag {systemtag}" : "Ο/Η {actor} πρόσθεσε σύστημα ετικετών {systemtag}",
    "System tag %1$s removed by the system" : "Η ετικέτα συστήματος %1$s αφαιρέθηκε από το σύστημα",
    "Removed system tag {systemtag}" : "Αφαιρέθηκε ετικέτα συστήματος {systemtag}",
    "Removed system tag %1$s" : "Αφαιρέθηκε ετικέτα συστήματος %1$s",
    "%1$s removed system tag %2$s" : "%1$s αφαίρεσε ετικέτα συστήματος %2$s",
    "{actor} removed system tag {systemtag}" : "Ο/η {actor} αφαίρεσε ετικέτα συστήματος {systemtag}",
    "You created system tag %1$s" : "Δημιουργήσατε ετικέτα συστήματος %1$s",
    "You created system tag {systemtag}" : "Δημιουργήσατε ετικέτα συστήματος {systemtag}",
    "%1$s created system tag %2$s" : "%1$s δημιούργησε ετικέτα συστήματος %2$s",
    "{actor} created system tag {systemtag}" : "{actor} δημιούργησε ετικέτα συστήματος {systemtag}",
    "You deleted system tag %1$s" : "Αφαιρέσατε ετικέτα συστήματος %1$s",
    "You deleted system tag {systemtag}" : "Αφαιρέσατε ετικέτα συστήματος {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s αφαίρεσε ετικέτα συστήματος %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} αφαίρεσε ετικέτα συστήματος {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ενημερώσατε ετικέτα συστήματος %2$s σε %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ενημερώσατε ετικέτα συστήματος {oldsystemtag} σε {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ενημέρωσε ετικέτα συστήματος %3$s ζε %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ενημέρωσε ετικέτα συστήματος {oldsystemtag} σε {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Η ετικέτα συστήματος %2$s προστέθηκε στο %1$s από το σύστημα",
    "System tag {systemtag} was added to {file} by the system" : "Η ετικέτα συστήματος {systemtag} προστέθηκε στο {file} από το σύστημα",
    "You added system tag %2$s to %1$s" : "Προσθέσατε ετικέτα συστήματος %2$s στο %1$s",
    "You added system tag {systemtag} to {file}" : "Προσθέσατε ετικέτα συστήματος {systemtag} στο {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s πρόσθεσε ετικέτα συστήματος %3$s στο %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} πρόσθεσε ετικέτα συστήματος {systemtag} στο {file}",
    "System tag %2$s was removed from %1$s by the system" : "Η ετικέτα συστήματος %2$s αφαιρέθηκε από %1$s από το σύστημα",
    "System tag {systemtag} was removed from {file} by the system" : "Η ετικέτα συστήματος {systemtag} αφαιρέθηκε από {file} από το σύστημα",
    "You removed system tag %2$s from %1$s" : "Αφαιρέσατε ετικέτα συστήματος %2$s από %1$s",
    "You removed system tag {systemtag} from {file}" : "Αφαιρέσατε ετικέτα συστήματος {systemtag} από {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s αφαίρεσε ετικέτα συστήματος %3$s από %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "Ο/Η {actor} αφαίρεσε ετικέτα συστήματος {systemtag} από {file}",
    "%s (restricted)" : "%s (περιορισμένο)",
    "%s (invisible)" : "%s (αόρατο)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Οι ετικέτες συστήματος</strong> για ένα αρχείο έχουν τροποποιηθεί",
    "Files" : "Αρχεία",
    "Tags" : "Ετικέτες",
    "All tagged %s …" : "Όλα με ετικέτα %s …",
    "tagged %s" : "με ετικέτα %s",
    "Collaborative tags" : "Ετικέτες συνεργασίας",
    "Collaborative tagging functionality which shares tags among people." : "Λειτουργία συνεργατικής επισήμανσης που μοιράζεται ετικέτες μεταξύ χρηστών.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Λειτουργία συνεργατικής επισήμανσης που μοιράζεται ετικέτες μεταξύ χρηστών. Ιδανικό για ομάδες.\n\t(Αν είστε πάροχος με εγκατάσταση πολλαπλών ενοικιαστών, συνιστάται η απενεργοποίηση αυτής της εφαρμογής καθώς οι ετικέτες μοιράζονται.)",
    "Public" : "Δημόσιο",
    "Restricted" : "Περιορισμένο",
    "Invisible" : "Αόρατο",
    "Created tag" : "Δημιουργήθηκε ετικέτα",
    "Failed to create tag" : "Αποτυχία δημιουργίας ετικέτας",
    "Updated tag" : "Ενημερώθηκε η ετικέτα",
    "Failed to update tag" : "Αποτυχία ενημέρωσης ετικέτας",
    "Deleted tag" : "Διαγράφηκε η ετικέτα",
    "Failed to delete tag" : "Αποτυχία διαγραφής ετικέτας",
    "Create or edit tags" : "Δημιουργία ή επεξεργασία ετικετών",
    "Search for a tag to edit" : "Αναζήτηση ετικέτας για επεξεργασία",
    "Collaborative tags …" : "Συνεργατικές ετικέτες…",
    "No tags to select" : "Δεν υπάρχουν διαθέσιμες ετικέτες για επιλογή",
    "Tag name" : "Όνομα ετικέτας",
    "Tag level" : "Επίπεδο ετικέτας",
    "Create" : "Δημιουργία",
    "Update" : "Ενημέρωση",
    "Delete" : "Διαγραφή",
    "Reset" : "Επαναφορά",
    "Loading …" : "Γίνεται φόρτωση…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["Η ετικέτα {tag1} θα οριστεί και η ετικέτα {tag2} θα αφαιρεθεί από 1 αρχείο.","Η ετικέτα {tag1} θα οριστεί και η ετικέτα {tag2} θα αφαιρεθεί από {count} αρχεία."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["Η ετικέτα {tag} θα οριστεί σε 1 αρχείο.","Η ετικέτα {tag} θα οριστεί σε {count} αρχεία."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["Η ετικέτα {tag} θα αφαιρεθεί από 1 αρχείο.","Η ετικέτα {tag} θα αφαιρεθεί από {count} αρχεία."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["Οι ετικέτες {tags} και {lastTag} θα οριστούν σε 1 αρχείο.","Οι ετικέτες {tags} και {lastTag} θα οριστούν σε {count} αρχεία."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["Οι ετικέτες {tags} και {lastTag} θα αφαιρεθούν από 1 αρχείο.","Οι ετικέτες {tags} και {lastTag} θα αφαιρεθούν από {count} αρχεία."],
    "{displayName} (hidden)" : "{displayName} (κρυφό)",
    "{displayName} (restricted)" : "{displayName} (περιορισμένο)",
    "Only admins can create new tags" : "Μόνο οι διαχειριστές μπορούν να δημιουργούν νέες ετικέτες",
    "Failed to apply tags changes" : "Αποτυχία εφαρμογής αλλαγών στις ετικέτες",
    "Manage tags" : "Διαχείριση ετικετών",
    "Applying tags changes…" : "Εφαρμογή αλλαγών στις ετικέτες…",
    "Search or create tag" : "Αναζήτηση ή δημιουργία ετικέτας",
    "Search tag" : "Αναζήτηση ετικέτας",
    "Change tag color" : "Αλλαγή χρώματος ετικέτας",
    "Create new tag" : "Δημιουργία νέας ετικέτας",
    "Choose tags for the selected files" : "Επιλογή ετικετών για τα επιλεγμένα αρχεία",
    "Cancel" : "Ακύρωση",
    "Apply" : "Εφαρμογή",
    "Failed to load tags" : "Απέτυχε η φόρτωση ετικετών",
    "Failed to load selected tags" : "Αποτυχία φόρτωσης των επιλεγμένων ετικετών",
    "Failed to select tag" : "Αποτυχία επιλογής ετικέτας",
    "System admin disabled tag creation. You can only use existing ones." : "Ο διαχειριστής του συστήματος απενεργοποίησε τη δημιουργία ετικετών. Μπορείτε να χρησιμοποιείτε μόνο τις υπάρχουσες.",
    "Loading collaborative tags …" : "Φόρτωση συνεργατικών ετικετών…",
    "Search or create collaborative tags" : "Αναζήτηση ή δημιουργία συνεργατικών ετικετών",
    "No tags to select, type to create a new tag" : "Δεν υπάρχουν διαθέσιμες ετικέτες για επιλογή, πληκτρολογήστε για να δημιουργήσετε μια νέα",
    "Unable to update setting" : "Αδυναμία ενημέρωσης ρύθμισης",
    "System tag creation is now restricted to administrators" : "Η δημιουργία ετικετών συστήματος περιορίζεται πλέον μόνο στους διαχειριστές",
    "System tag creation is now allowed for everybody" : "Η δημιουργία ετικετών συστήματος επιτρέπεται πλέον σε όλους",
    "System tag management" : "Διαχείριση ετικετών συστήματος",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Αν ενεργοποιηθεί, μόνο οι διαχειριστές μπορούν να δημιουργούν και να επεξεργάζονται ετικέτες. Οι χρήστες μπορούν ακόμα να τις αναθέτουν και να τις αφαιρούν από αρχεία.",
    "Restrict tag creation and editing to administrators" : "Περιορισμός δημιουργίας και επεξεργασίας ετικετών μόνο σε διαχειριστές",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Οι ετικέτες σε συνεργασία είναι διαθέσιμες για όλους τους χρήστες. Οι περιορισμένες ετικέτες είναι ορατές στους χρήστες, αλλά δεν μπορούν να τους ανατεθούν. Οι κρυφές ετικέτες είναι για εσωτερική χρήση, όμως οι χρήστες δεν μπορούν να τις δουν ή να τις αναθέσουν.",
    "Assigned collaborative tags" : "Ανατεθειμένες συνεργατικές ετικέτες",
    "Open in Files" : "Άνοιγμα στα Αρχεία",
    "List of tags and their associated files and folders." : "Λίστα ετικετών και των σχετικών αρχείων και φακέλων.",
    "No tags found" : "Δεν βρέθηκαν ετικέτες",
    "Tags you have created will show up here." : "Οι ετικέτες που έχετε δημιουργήσει θα εμφανίζονται εδώ.",
    "Failed to load tag" : "Αποτυχία φόρτωσης ετικέτας",
    "Failed to load last used tags" : "Αποτυχία φόρτωσης των τελευταίων χρησιμοποιημένων ετικετών",
    "Missing \"Content-Location\" header" : "Λείπει η κεφαλίδα \"Content-Location\"",
    "A tag with the same name already exists" : "Υπάρχει ήδη ετικέτα με το ίδιο όνομα",
    "Failed to load tags for file" : "Αποτυχία φόρτωσης ετικετών για το αρχείο",
    "Failed to set tag for file" : "Αποτυχία ορισμού ετικέτας για το αρχείο",
    "Failed to delete tag for file" : "Αποτυχία διαγραφής ετικέτας για το αρχείο",
    "File tags modification canceled" : "Η τροποποίηση ετικετών αρχείου ακυρώθηκε",
    "Select or create tags to apply to all selected files" : "Επιλέξτε ή δημιουργήστε ετικέτες για εφαρμογή σε όλα τα επιλεγμένα αρχεία",
    "Select tags to apply to all selected files" : "Επιλέξτε ετικέτες για εφαρμογή σε όλα τα επιλεγμένα αρχεία",
    "Apply changes" : "Εφαρμογή αλλαγών"
},
"nplurals=2; plural=(n != 1);");
